# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/pgc/gateway/player/v2/playurl.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,bilibili/pgc/gateway/player/v2/playurl.proto\x12\x1e\x62ilibili.pgc.gateway.player.v2\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa8\x01\n\tAnimation\x12`\n\x15qn_svga_animation_map\x18\x01 \x03(\x0b\x32\x41.bilibili.pgc.gateway.player.v2.Animation.QnSvgaAnimationMapEntry\x1a\x39\n\x17QnSvgaAnimationMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbe\x01\n\x12\x41udioMaterialProto\x12\x10\n\x08\x61udio_id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0f\n\x07\x65\x64ition\x18\x03 \x01(\t\x12\x11\n\tperson_id\x18\x04 \x01(\x04\x12\x13\n\x0bperson_name\x18\x05 \x01(\t\x12\x15\n\rperson_avatar\x18\x06 \x01(\t\x12\x37\n\x05\x61udio\x18\x07 \x03(\x0b\x32(.bilibili.pgc.gateway.player.v2.DashItem\"\xae\x01\n\tBadgeInfo\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x10\n\x08\x62g_color\x18\x02 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x03 \x01(\t\x12\x12\n\ntext_color\x18\x04 \x01(\t\x12H\n\x11\x62g_gradient_color\x18\x05 \x01(\x0b\x32-.bilibili.pgc.gateway.player.v2.GradientColor\x12\x0b\n\x03img\x18\x06 \x01(\t\"V\n\rBottomDisplay\x12\x37\n\x05title\x18\x01 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.TextInfo\x12\x0c\n\x04icon\x18\x02 \x01(\t\"\xdd\x05\n\nButtonInfo\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\x12\x10\n\x08\x62g_color\x18\x04 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x05 \x01(\t\x12\x0c\n\x04link\x18\x06 \x01(\t\x12\x13\n\x0b\x61\x63tion_type\x18\x07 \x01(\t\x12=\n\nbadge_info\x18\x08 \x01(\x0b\x32).bilibili.pgc.gateway.player.v2.BadgeInfo\x12\x36\n\x06report\x18\t \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.Report\x12\x1f\n\x17left_strikethrough_text\x18\n \x01(\t\x12\x42\n\x10simple_text_info\x18\x0b \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.TextInfo\x12\x17\n\x0fsimple_bg_color\x18\x0c \x01(\t\x12\x1d\n\x15simple_bg_color_night\x18\r \x01(\t\x12H\n\x11\x62g_gradient_color\x18\x0e \x01(\x0b\x32-.bilibili.pgc.gateway.player.v2.GradientColor\x12^\n\x13order_report_params\x18\x0f \x03(\x0b\x32\x41.bilibili.pgc.gateway.player.v2.ButtonInfo.OrderReportParamsEntry\x12=\n\ntask_param\x18\x10 \x01(\x0b\x32).bilibili.pgc.gateway.player.v2.TaskParam\x12\x0f\n\x07pc_link\x18\x11 \x01(\t\x1a\x38\n\x16OrderReportParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\")\n\x08\x43\x61stTips\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xcb\x01\n\x08\x43lipInfo\x12\x13\n\x0bmaterial_no\x18\x01 \x01(\x03\x12\r\n\x05start\x18\x02 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x05\x12;\n\tclip_type\x18\x04 \x01(\x0e\x32(.bilibili.pgc.gateway.player.v2.ClipType\x12\x12\n\ntoast_text\x18\x05 \x01(\t\x12=\n\nmulti_view\x18\x06 \x01(\x0b\x32).bilibili.pgc.gateway.player.v2.MultiView\"/\n\x10\x43ontinuePlayInfo\x12\x1b\n\x13\x63ontinue_play_ep_id\x18\x01 \x01(\x03\"\x8e\x02\n\x06\x43oupon\x12\x14\n\x0c\x63oupon_token\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\x03\x12\r\n\x05value\x18\x03 \x01(\t\x12\x10\n\x08use_desc\x18\x04 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x06 \x01(\t\x12\x17\n\x0fpay_button_text\x18\x07 \x01(\t\x12$\n\x1cpay_button_text_line_through\x18\x08 \x01(\t\x12\x13\n\x0breal_amount\x18\t \x01(\t\x12/\n\x0b\x65xpire_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05otype\x18\x0b \x01(\x03\x12\x0e\n\x06\x61mount\x18\x0c \x01(\t\"\x81\x01\n\nCouponInfo\x12:\n\x05toast\x18\x01 \x01(\x0b\x32+.bilibili.pgc.gateway.player.v2.CouponToast\x12\x37\n\x07pop_win\x18\x02 \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.PopWin\";\n\x0e\x43ouponTextInfo\x12\x18\n\x10positive_preview\x18\x01 \x01(\t\x12\x0f\n\x07section\x18\x02 \x01(\t\"\x8c\x01\n\x0b\x43ouponToast\x12\x41\n\ttext_info\x18\x01 \x01(\x0b\x32..bilibili.pgc.gateway.player.v2.CouponTextInfo\x12:\n\x06\x62utton\x18\x02 \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.ButtonInfo\"\xa6\x01\n\x08\x44\x61shItem\x12\n\n\x02id\x18\x01 \x01(\r\x12\x10\n\x08\x62\x61se_url\x18\x02 \x01(\t\x12\x12\n\nbackup_url\x18\x03 \x03(\t\x12\x11\n\tbandwidth\x18\x04 \x01(\r\x12\x0f\n\x07\x63odecid\x18\x05 \x01(\r\x12\x0b\n\x03md5\x18\x06 \x01(\t\x12\x0c\n\x04size\x18\x07 \x01(\x04\x12\x12\n\nframe_rate\x18\x08 \x01(\t\x12\x15\n\rwidevine_pssh\x18\t \x01(\t\"\xe0\x01\n\tDashVideo\x12\x10\n\x08\x62\x61se_url\x18\x01 \x01(\t\x12\x12\n\nbackup_url\x18\x02 \x03(\t\x12\x11\n\tbandwidth\x18\x03 \x01(\r\x12\x0f\n\x07\x63odecid\x18\x04 \x01(\r\x12\x0b\n\x03md5\x18\x05 \x01(\t\x12\x0c\n\x04size\x18\x06 \x01(\x04\x12\x10\n\x08\x61udio_id\x18\x07 \x01(\r\x12\x12\n\nno_rexcode\x18\x08 \x01(\x08\x12\x12\n\nframe_rate\x18\t \x01(\t\x12\r\n\x05width\x18\n \x01(\x05\x12\x0e\n\x06height\x18\x0b \x01(\x05\x12\x15\n\rwidevine_pssh\x18\x0c \x01(\t\"*\n\x0b\x44\x61taControl\x12\x1b\n\x13need_watch_progress\x18\x01 \x01(\x08\"\xc8\x05\n\x06\x44ialog\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x12\n\nstyle_type\x18\x04 \x01(\t\x12<\n\x06\x63onfig\x18\x05 \x01(\x0b\x32,.bilibili.pgc.gateway.player.v2.DialogConfig\x12\x37\n\x05title\x18\x06 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.TextInfo\x12:\n\x08subtitle\x18\x07 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.TextInfo\x12\x38\n\x05image\x18\x08 \x01(\x0b\x32).bilibili.pgc.gateway.player.v2.ImageInfo\x12:\n\x06\x62utton\x18\t \x03(\x0b\x32*.bilibili.pgc.gateway.player.v2.ButtonInfo\x12?\n\x0b\x62ottom_desc\x18\n \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.ButtonInfo\x12\x36\n\x06report\x18\x0b \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.Report\x12\x16\n\x0e\x63ount_down_sec\x18\x0c \x01(\x05\x12\x43\n\x11right_bottom_desc\x18\r \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.TextInfo\x12\x45\n\x0e\x62ottom_display\x18\x0e \x03(\x0b\x32-.bilibili.pgc.gateway.player.v2.BottomDisplay\x12;\n\tplay_list\x18\x0f \x03(\x0b\x32(.bilibili.pgc.gateway.player.v2.PlayList\"\xb3\x01\n\x0c\x44ialogConfig\x12\x15\n\ris_show_cover\x18\x01 \x01(\x08\x12\x1d\n\x15is_orientation_enable\x18\x02 \x01(\x08\x12\x1f\n\x17is_nested_scroll_enable\x18\x03 \x01(\x08\x12\"\n\x1ais_force_halfscreen_enable\x18\x04 \x01(\x08\x12(\n is_background_translucent_enable\x18\x05 \x01(\x08\":\n\tDimension\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0e\n\x06height\x18\x02 \x01(\x05\x12\x0e\n\x06rotate\x18\x03 \x01(\x05\"\xab\x01\n\tDolbyItem\x12<\n\x04type\x18\x01 \x01(\x0e\x32..bilibili.pgc.gateway.player.v2.DolbyItem.Type\x12\x37\n\x05\x61udio\x18\x02 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.DashItem\"\'\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x43OMMON\x10\x01\x12\t\n\x05\x41TMOS\x10\x02\"O\n\x07\x45ndPage\x12\x36\n\x06\x64ialog\x18\x01 \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.Dialog\x12\x0c\n\x04hide\x18\x02 \x01(\x08\">\n\rEpInlineVideo\x12\x13\n\x0bmaterial_no\x18\x01 \x01(\x03\x12\x0b\n\x03\x61id\x18\x02 \x01(\x03\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\"\xc6\x01\n\x18\x45pisodeAdvertisementInfo\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\x12\x1d\n\x15\x66ollow_video_bnt_flag\x18\x04 \x01(\x05\x12\x18\n\x10next_video_title\x18\x05 \x01(\t\x12\x17\n\x0fnext_video_link\x18\x06 \x01(\t\x12\x0b\n\x03\x63id\x18\x07 \x01(\x03\x12\x11\n\tseason_id\x18\x08 \x01(\x05\x12\x0e\n\x06\x66ollow\x18\t \x01(\x05\"\xfe\x01\n\x0b\x45pisodeInfo\x12\r\n\x05\x65p_id\x18\x01 \x01(\x05\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\x0b\n\x03\x61id\x18\x03 \x01(\x03\x12\x11\n\tep_status\x18\x04 \x01(\x03\x12?\n\x0bseason_info\x18\x05 \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.SeasonInfo\x12\r\n\x05\x63over\x18\x06 \x01(\t\x12\r\n\x05title\x18\x07 \x01(\t\x12@\n\x0binteraction\x18\x08 \x01(\x0b\x32+.bilibili.pgc.gateway.player.v2.Interaction\x12\x12\n\nlong_title\x18\t \x01(\t\"&\n\nEpPreVideo\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\"\xa8\x02\n\x10\x45pPublicityVideo\x12\x43\n\x04type\x18\x01 \x01(\x0e\x32\x35.bilibili.pgc.gateway.player.v2.EpPublicityVideo.Type\x12\x42\n\x0c\x65p_pre_video\x18\x02 \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.EpPreVideoH\x00\x12H\n\x0f\x65p_inline_video\x18\x03 \x01(\x0b\x32-.bilibili.pgc.gateway.player.v2.EpInlineVideoH\x00\"9\n\x04Type\x12\x10\n\x0c\x44\x41TA_NOT_SET\x10\x00\x12\x10\n\x0c\x45P_PRE_VIDEO\x10\x02\x12\r\n\tEP_INLINE\x10\x03\x42\x06\n\x04\x64\x61ta\"=\n\x05\x45vent\x12\x34\n\x05shake\x18\x01 \x01(\x0b\x32%.bilibili.pgc.gateway.player.v2.Shake\"\x88\x01\n\x0b\x46reyaConfig\x12\x0c\n\x04\x64\x65sc\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\x05\x12\x12\n\nissued_cnt\x18\x03 \x01(\x05\x12\x16\n\x0eis_always_show\x18\x04 \x01(\x08\x12\x15\n\rscreen_number\x18\x05 \x01(\x05\x12\x1a\n\x12\x66ull_screen_number\x18\x06 \x01(\x05\"7\n\rGradientColor\x12\x13\n\x0bstart_color\x18\x01 \x01(\t\x12\x11\n\tend_color\x18\x02 \x01(\t\"\xab\x03\n\x17HighDefinitionTrialInfo\x12\x12\n\ntrial_able\x18\x01 \x01(\x08\x12\x17\n\x0fremaining_times\x18\x02 \x01(\x05\x12\r\n\x05start\x18\x03 \x01(\x05\x12\x13\n\x0btime_length\x18\x04 \x01(\x05\x12:\n\x0bstart_toast\x18\x05 \x01(\x0b\x32%.bilibili.pgc.gateway.player.v2.Toast\x12\x38\n\tend_toast\x18\x06 \x01(\x0b\x32%.bilibili.pgc.gateway.player.v2.Toast\x12\x36\n\x06report\x18\x07 \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.Report\x12H\n\x14quality_open_tip_btn\x18\x08 \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.ButtonInfo\x12G\n\x13no_longer_trial_btn\x18\t \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.ButtonInfo\":\n\x0bHistoryNode\x12\x0f\n\x07node_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\"\x18\n\tImageInfo\x12\x0b\n\x03url\x18\x01 \x01(\t\"\x8c\x01\n\x0bInteraction\x12\x41\n\x0chistory_node\x18\x01 \x01(\x0b\x32+.bilibili.pgc.gateway.player.v2.HistoryNode\x12\x15\n\rgraph_version\x18\x02 \x01(\x03\x12\x0b\n\x03msg\x18\x03 \x01(\t\x12\x16\n\x0eis_interaction\x18\x04 \x01(\x08\"N\n\tMultiView\x12\x17\n\x0f\x62utton_material\x18\x01 \x01(\t\x12\r\n\x05\x65p_id\x18\x02 \x01(\x03\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\x12\x0c\n\x04\x61vid\x18\x04 \x01(\x03\"\xee\x04\n\x06PayTip\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\x05\x12\x11\n\tshow_type\x18\x05 \x01(\x05\x12\x0b\n\x03img\x18\x06 \x01(\t\x12\x14\n\x0c\x62g_day_color\x18\x07 \x01(\t\x12\x16\n\x0e\x62g_night_color\x18\x08 \x01(\t\x12\x15\n\rbg_line_color\x18\t \x01(\t\x12\x1b\n\x13\x62g_night_line_color\x18\n \x01(\t\x12\x12\n\ntext_color\x18\x0b \x01(\t\x12\x18\n\x10text_night_color\x18\x0c \x01(\t\x12\x17\n\x0fview_start_time\x18\r \x01(\x03\x12:\n\x06\x62utton\x18\x0e \x03(\x0b\x32*.bilibili.pgc.gateway.player.v2.ButtonInfo\x12\x15\n\rurl_open_type\x18\x0f \x01(\x05\x12\x36\n\x06report\x18\x10 \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.Report\x12\x13\n\x0b\x61ngle_style\x18\x11 \x01(\x05\x12\x13\n\x0breport_type\x18\x12 \x01(\x05\x12Z\n\x13order_report_params\x18\x13 \x03(\x0b\x32=.bilibili.pgc.gateway.player.v2.PayTip.OrderReportParamsEntry\x12\x18\n\x10giant_screen_img\x18\x14 \x01(\t\x1a\x38\n\x16OrderReportParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x86\x07\n\x0fPlayAbilityConf\x12\x1f\n\x17\x62\x61\x63kground_play_disable\x18\x01 \x01(\x08\x12\x14\n\x0c\x66lip_disable\x18\x02 \x01(\x08\x12\x14\n\x0c\x63\x61st_disable\x18\x03 \x01(\x08\x12\x18\n\x10\x66\x65\x65\x64\x62\x61\x63k_disable\x18\x04 \x01(\x08\x12\x18\n\x10subtitle_disable\x18\x05 \x01(\x08\x12\x1d\n\x15playback_rate_disable\x18\x06 \x01(\x08\x12\x17\n\x0ftime_up_disable\x18\x07 \x01(\x08\x12\x1d\n\x15playback_mode_disable\x18\x08 \x01(\x08\x12\x1a\n\x12scale_mode_disable\x18\t \x01(\x08\x12\x14\n\x0clike_disable\x18\n \x01(\x08\x12\x17\n\x0f\x64islike_disable\x18\x0b \x01(\x08\x12\x14\n\x0c\x63oin_disable\x18\x0c \x01(\x08\x12\x14\n\x0c\x65lec_disable\x18\r \x01(\x08\x12\x15\n\rshare_disable\x18\x0e \x01(\x08\x12\x1b\n\x13screen_shot_disable\x18\x0f \x01(\x08\x12\x1b\n\x13lock_screen_disable\x18\x10 \x01(\x08\x12\x19\n\x11recommend_disable\x18\x11 \x01(\x08\x12\x1e\n\x16playback_speed_disable\x18\x12 \x01(\x08\x12\x1a\n\x12\x64\x65\x66inition_disable\x18\x13 \x01(\x08\x12\x1a\n\x12selections_disable\x18\x14 \x01(\x08\x12\x14\n\x0cnext_disable\x18\x15 \x01(\x08\x12\x17\n\x0f\x65\x64it_dm_disable\x18\x16 \x01(\x08\x12\x1c\n\x14small_window_disable\x18\x17 \x01(\x08\x12\x15\n\rshake_disable\x18\x18 \x01(\x08\x12\x18\n\x10outer_dm_disable\x18\x19 \x01(\x08\x12\x18\n\x10inner_dm_disable\x18\x1a \x01(\x08\x12\x1b\n\x13\x66reya_enter_disable\x18\x1b \x01(\x08\x12\x15\n\rdolby_disable\x18\x1c \x01(\x08\x12\x1a\n\x12\x66reya_full_disable\x18\x1d \x01(\x08\x12 \n\x18skip_oped_switch_disable\x18\x1e \x01(\x08\x12\x1d\n\x15record_screen_disable\x18\x1f \x01(\x08\x12\x1e\n\x16\x63olor_optimize_disable\x18  \x01(\x08\x12\x17\n\x0f\x64ubbing_disable\x18! \x01(\x08\"\xb2\x01\n\x12PlayAbilityExtConf\x12\x1c\n\x14\x61llow_close_subtitle\x18\x01 \x01(\x08\x12\x41\n\x0c\x66reya_config\x18\x02 \x01(\x0b\x32+.bilibili.pgc.gateway.player.v2.FreyaConfig\x12;\n\tcast_tips\x18\x03 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.CastTips\"\xbc\x01\n\x0fPlayDubbingInfo\x12L\n\x10\x62\x61\x63kground_audio\x18\x01 \x01(\x0b\x32\x32.bilibili.pgc.gateway.player.v2.AudioMaterialProto\x12G\n\x0frole_audio_list\x18\x02 \x03(\x0b\x32..bilibili.pgc.gateway.player.v2.RoleAudioProto\x12\x12\n\nguide_text\x18\x03 \x01(\t\"Y\n\x0bPlayExtInfo\x12J\n\x11play_dubbing_info\x18\x01 \x01(\x0b\x32/.bilibili.pgc.gateway.player.v2.PlayDubbingInfo\"\x88\x01\n\x08PlayList\x12\x11\n\tseason_id\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x0c\n\x04link\x18\x04 \x01(\t\x12=\n\nbadge_info\x18\x05 \x01(\x0b\x32).bilibili.pgc.gateway.player.v2.BadgeInfo\"\x94\t\n\x14PlayViewBusinessInfo\x12\x12\n\nis_preview\x18\x01 \x01(\x08\x12\n\n\x02\x62p\x18\x02 \x01(\x08\x12\x14\n\x0cmarlin_token\x18\x03 \x01(\t\x12\x1c\n\x14playback_speed_color\x18\x04 \x01(\t\x12L\n\x12\x63ontinue_play_info\x18\x05 \x01(\x0b\x32\x30.bilibili.pgc.gateway.player.v2.ContinuePlayInfo\x12;\n\tclip_info\x18\x06 \x03(\x0b\x32(.bilibili.pgc.gateway.player.v2.ClipInfo\x12?\n\x0binline_type\x18\x07 \x01(\x0e\x32*.bilibili.pgc.gateway.player.v2.InlineType\x12\x19\n\x11\x65p_whole_duration\x18\x08 \x01(\x05\x12<\n\tdimension\x18\t \x01(\x0b\x32).bilibili.pgc.gateway.player.v2.Dimension\x12`\n\x0fquality_ext_map\x18\n \x03(\x0b\x32G.bilibili.pgc.gateway.player.v2.PlayViewBusinessInfo.QualityExtMapEntry\x12Q\n\x07\x65xp_map\x18\x0b \x03(\x0b\x32@.bilibili.pgc.gateway.player.v2.PlayViewBusinessInfo.ExpMapEntry\x12\x42\n\rdrm_tech_type\x18\x0c \x01(\x0e\x32+.bilibili.pgc.gateway.player.v2.DrmTechType\x12\x19\n\x11limit_action_type\x18\r \x01(\x05\x12\x0e\n\x06is_drm\x18\x0e \x01(\x08\x12?\n\x0brecord_info\x18\x0f \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.RecordInfo\x12\x12\n\nvip_status\x18\x10 \x01(\x05\x12\x13\n\x0bis_live_pre\x18\x11 \x01(\x08\x12\x41\n\x0c\x65pisode_info\x18\x12 \x01(\x0b\x32+.bilibili.pgc.gateway.player.v2.EpisodeInfo\x12\\\n\x1a\x65pisode_advertisement_info\x18\x13 \x01(\x0b\x32\x38.bilibili.pgc.gateway.player.v2.EpisodeAdvertisementInfo\x12?\n\x0buser_status\x18\x14 \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.UserStatus\x1a\x64\n\x12QualityExtMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12=\n\x05value\x18\x02 \x01(\x0b\x32..bilibili.pgc.gateway.player.v2.QualityExtInfo:\x02\x38\x01\x1a-\n\x0b\x45xpMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"\xdc\x03\n\rPlayViewReply\x12=\n\nvideo_info\x18\x01 \x01(\x0b\x32).bilibili.pgc.gateway.player.v2.VideoInfo\x12\x42\n\tplay_conf\x18\x02 \x01(\x0b\x32/.bilibili.pgc.gateway.player.v2.PlayAbilityConf\x12\x46\n\x08\x62usiness\x18\x03 \x01(\x0b\x32\x34.bilibili.pgc.gateway.player.v2.PlayViewBusinessInfo\x12\x34\n\x05\x65vent\x18\x04 \x01(\x0b\x32%.bilibili.pgc.gateway.player.v2.Event\x12;\n\tview_info\x18\x05 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.ViewInfo\x12I\n\rplay_ext_conf\x18\x06 \x01(\x0b\x32\x32.bilibili.pgc.gateway.player.v2.PlayAbilityExtConf\x12\x42\n\rplay_ext_info\x18\x07 \x01(\x0b\x32+.bilibili.pgc.gateway.player.v2.PlayExtInfo\"\xd2\x04\n\x0bPlayViewReq\x12\x0c\n\x04\x65pid\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\n\n\x02qn\x18\x03 \x01(\x03\x12\r\n\x05\x66nver\x18\x04 \x01(\x05\x12\r\n\x05\x66nval\x18\x05 \x01(\x05\x12\x10\n\x08\x64ownload\x18\x06 \x01(\r\x12\x12\n\nforce_host\x18\x07 \x01(\x05\x12\r\n\x05\x66ourk\x18\x08 \x01(\x08\x12\r\n\x05spmid\x18\t \x01(\t\x12\x12\n\nfrom_spmid\x18\n \x01(\t\x12\x16\n\x0eteenagers_mode\x18\x0b \x01(\x05\x12\x43\n\x11prefer_codec_type\x18\x0c \x01(\x0e\x32(.bilibili.pgc.gateway.player.v2.CodeType\x12\x12\n\nis_preview\x18\r \x01(\x08\x12\x0f\n\x07room_id\x18\x0e \x01(\x03\x12\x19\n\x11is_need_view_info\x18\x0f \x01(\x08\x12\x43\n\rscene_control\x18\x10 \x01(\x0b\x32,.bilibili.pgc.gateway.player.v2.SceneControl\x12\x41\n\x0cinline_scene\x18\x11 \x01(\x0e\x32+.bilibili.pgc.gateway.player.v2.InlineScene\x12\x13\n\x0bmaterial_no\x18\x12 \x01(\x03\x12\x16\n\x0esecurity_level\x18\x13 \x01(\x05\x12\x11\n\tseason_id\x18\x14 \x01(\x03\x12\x41\n\x0c\x64\x61ta_control\x18\x15 \x01(\x0b\x32+.bilibili.pgc.gateway.player.v2.DataControl\"\xfb\x02\n\x06PopWin\x12\r\n\x05title\x18\x01 \x01(\t\x12\x36\n\x06\x63oupon\x18\x02 \x03(\x0b\x32&.bilibili.pgc.gateway.player.v2.Coupon\x12:\n\x06\x62utton\x18\x03 \x03(\x0b\x32*.bilibili.pgc.gateway.player.v2.ButtonInfo\x12\x13\n\x0b\x62ottom_text\x18\x04 \x01(\t\x12;\n\tpop_title\x18\x05 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.TextInfo\x12:\n\x08subtitle\x18\x06 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.TextInfo\x12?\n\x0b\x62ottom_desc\x18\x07 \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.ButtonInfo\x12\r\n\x05\x63over\x18\x08 \x01(\t\x12\x10\n\x08pop_type\x18\t \x01(\t\"\xdc\x03\n\tPromptBar\x12\x37\n\x05title\x18\x01 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.TextInfo\x12;\n\tsub_title\x18\x02 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.TextInfo\x12\x16\n\x0esub_title_icon\x18\x03 \x01(\t\x12\x10\n\x08\x62g_image\x18\x04 \x01(\t\x12H\n\x11\x62g_gradient_color\x18\x05 \x01(\x0b\x32-.bilibili.pgc.gateway.player.v2.GradientColor\x12:\n\x06\x62utton\x18\x06 \x03(\x0b\x32*.bilibili.pgc.gateway.player.v2.ButtonInfo\x12\x36\n\x06report\x18\x07 \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.Report\x12\x1b\n\x13\x66ull_screen_ip_icon\x18\x08 \x01(\t\x12T\n\x1d\x66ull_screen_bg_gradient_color\x18\t \x01(\x0b\x32-.bilibili.pgc.gateway.player.v2.GradientColor\"\'\n\x0eQualityExtInfo\x12\x15\n\rtrial_support\x18\x01 \x01(\x08\"1\n\nRecordInfo\x12\x0e\n\x06record\x18\x01 \x01(\t\x12\x13\n\x0brecord_icon\x18\x02 \x01(\t\"H\n\x06Report\x12\x15\n\rshow_event_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63lick_event_id\x18\x02 \x01(\t\x12\x0f\n\x07\x65xtends\x18\x03 \x01(\t\"h\n\x0bResponseUrl\x12\r\n\x05order\x18\x01 \x01(\r\x12\x0e\n\x06length\x18\x02 \x01(\x04\x12\x0c\n\x04size\x18\x03 \x01(\x04\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x12\n\nbackup_url\x18\x05 \x03(\t\x12\x0b\n\x03md5\x18\x06 \x01(\t\"\x1b\n\x06Rights\x12\x11\n\tcan_watch\x18\x01 \x01(\x05\"\x9a\x01\n\x0eRoleAudioProto\x12\x0f\n\x07role_id\x18\x01 \x01(\x03\x12\x11\n\trole_name\x18\x02 \x01(\t\x12\x13\n\x0brole_avatar\x18\x03 \x01(\t\x12O\n\x13\x61udio_material_list\x18\x04 \x03(\x0b\x32\x32.bilibili.pgc.gateway.player.v2.AudioMaterialProto\"u\n\x0cSceneControl\x12\x14\n\x0c\x66\x61v_playlist\x18\x01 \x01(\x08\x12\x14\n\x0csmall_window\x18\x02 \x01(\x08\x12\x0b\n\x03pip\x18\x03 \x01(\x08\x12\x15\n\rwas_he_inline\x18\x04 \x01(\x08\x12\x15\n\ris_need_trial\x18\x05 \x01(\x08\"\x8a\x01\n\x06Scheme\x12\x46\n\x0b\x61\x63tion_type\x18\x01 \x01(\x0e\x32\x31.bilibili.pgc.gateway.player.v2.Scheme.ActionType\x12\r\n\x05toast\x18\x02 \x01(\t\")\n\nActionType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nSHOW_TOAST\x10\x01\"\xaf\x01\n\nSeasonInfo\x12\x11\n\tseason_id\x18\x01 \x01(\x05\x12\x13\n\x0bseason_type\x18\x02 \x01(\x05\x12\x15\n\rseason_status\x18\x03 \x01(\x05\x12\r\n\x05\x63over\x18\x04 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t\x12\x36\n\x06rights\x18\x06 \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.Rights\x12\x0c\n\x04mode\x18\x07 \x01(\x05\"L\n\x0cSegmentVideo\x12<\n\x07segment\x18\x01 \x03(\x0b\x32+.bilibili.pgc.gateway.player.v2.ResponseUrl\"\x15\n\x05Shake\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\"\xd5\x01\n\x06Stream\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.StreamInfo\x12?\n\ndash_video\x18\x02 \x01(\x0b\x32).bilibili.pgc.gateway.player.v2.DashVideoH\x00\x12\x45\n\rsegment_video\x18\x03 \x01(\x0b\x32,.bilibili.pgc.gateway.player.v2.SegmentVideoH\x00\x42\t\n\x07\x63ontent\"\xfc\x02\n\nStreamInfo\x12\x0f\n\x07quality\x18\x01 \x01(\x05\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08\x65rr_code\x18\x04 \x01(\x05\x12:\n\x05limit\x18\x05 \x01(\x0b\x32+.bilibili.pgc.gateway.player.v2.StreamLimit\x12\x10\n\x08need_vip\x18\x06 \x01(\x08\x12\x12\n\nneed_login\x18\x07 \x01(\x08\x12\x0e\n\x06intact\x18\x08 \x01(\x08\x12\x11\n\tattribute\x18\n \x01(\x03\x12\x17\n\x0fnew_description\x18\x0b \x01(\t\x12\x14\n\x0c\x64isplay_desc\x18\x0c \x01(\t\x12\x13\n\x0bsuperscript\x18\r \x01(\t\x12\x36\n\x06scheme\x18\x0e \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.Scheme\x12\x13\n\x0bsupport_drm\x18\x0f \x01(\x08\x12\x10\n\x08subtitle\x18\x10 \x01(\t\"6\n\x0bStreamLimit\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0b\n\x03msg\x18\x03 \x01(\t\"D\n\tTaskParam\x12\x11\n\ttask_type\x18\x01 \x01(\t\x12\x13\n\x0b\x61\x63tivity_id\x18\x02 \x01(\x03\x12\x0f\n\x07tips_id\x18\x03 \x01(\x03\"F\n\x08TextInfo\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\"\x83\x03\n\x05Toast\x12\x0c\n\x04text\x18\x01 \x01(\t\x12:\n\x06\x62utton\x18\x02 \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.ButtonInfo\x12\x17\n\x0fshow_style_type\x18\x03 \x01(\x05\x12\x0c\n\x04icon\x18\x04 \x01(\t\x12<\n\ntoast_text\x18\x05 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v2.TextInfo\x12\x36\n\x06report\x18\x06 \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.Report\x12Y\n\x13order_report_params\x18\x07 \x03(\x0b\x32<.bilibili.pgc.gateway.player.v2.Toast.OrderReportParamsEntry\x1a\x38\n\x16OrderReportParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc2\x01\n\nUserStatus\x12\x11\n\tpay_check\x18\x01 \x01(\x08\x12\x0f\n\x07sponsor\x18\x02 \x01(\x08\x12\x45\n\x0ewatch_progress\x18\x03 \x01(\x0b\x32-.bilibili.pgc.gateway.player.v2.WatchProgress\x12I\n\x12\x61id_watch_progress\x18\x04 \x01(\x0b\x32-.bilibili.pgc.gateway.player.v2.WatchProgress\"\x8c\x02\n\tVideoInfo\x12\x0f\n\x07quality\x18\x01 \x01(\r\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x12\n\ntimelength\x18\x03 \x01(\x04\x12\x15\n\rvideo_codecid\x18\x04 \x01(\r\x12;\n\x0bstream_list\x18\x05 \x03(\x0b\x32&.bilibili.pgc.gateway.player.v2.Stream\x12<\n\ndash_audio\x18\x06 \x03(\x0b\x32(.bilibili.pgc.gateway.player.v2.DashItem\x12\x38\n\x05\x64olby\x18\x07 \x01(\x0b\x32).bilibili.pgc.gateway.player.v2.DolbyItem\"\xb0\x08\n\x08ViewInfo\x12\x36\n\x06\x64ialog\x18\x01 \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.Dialog\x12\x34\n\x05toast\x18\x02 \x01(\x0b\x32%.bilibili.pgc.gateway.player.v2.Toast\x12?\n\x0b\x63oupon_info\x18\x03 \x01(\x0b\x32*.bilibili.pgc.gateway.player.v2.CouponInfo\x12\x1b\n\x13\x64\x65mand_no_pay_epids\x18\x04 \x03(\x03\x12\x39\n\x08\x65nd_page\x18\x05 \x01(\x0b\x32\'.bilibili.pgc.gateway.player.v2.EndPage\x12K\n\nexp_config\x18\x06 \x03(\x0b\x32\x37.bilibili.pgc.gateway.player.v2.ViewInfo.ExpConfigEntry\x12\x37\n\x07pop_win\x18\x07 \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.PopWin\x12G\n\x14try_watch_prompt_bar\x18\x08 \x01(\x0b\x32).bilibili.pgc.gateway.player.v2.PromptBar\x12\x37\n\x07pay_tip\x18\t \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.PayTip\x12[\n\x1ahigh_definition_trial_info\x18\n \x01(\x0b\x32\x37.bilibili.pgc.gateway.player.v2.HighDefinitionTrialInfo\x12K\n\next_dialog\x18\x0b \x03(\x0b\x32\x37.bilibili.pgc.gateway.player.v2.ViewInfo.ExtDialogEntry\x12<\n\tanimation\x18\x0c \x01(\x0b\x32).bilibili.pgc.gateway.player.v2.Animation\x12I\n\text_toast\x18\r \x03(\x0b\x32\x36.bilibili.pgc.gateway.player.v2.ViewInfo.ExtToastEntry\x1a\x30\n\x0e\x45xpConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1aX\n\x0e\x45xtDialogEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.bilibili.pgc.gateway.player.v2.Dialog:\x02\x38\x01\x1aV\n\rExtToastEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.bilibili.pgc.gateway.player.v2.Toast:\x02\x38\x01\"\xf3\x01\n\rWatchProgress\x12\x12\n\nlast_ep_id\x18\x01 \x01(\x05\x12\x15\n\rlast_ep_index\x18\x02 \x01(\t\x12\x10\n\x08progress\x18\x03 \x01(\x03\x12\x15\n\rlast_play_cid\x18\x04 \x01(\x03\x12\x34\n\x05toast\x18\x05 \x01(\x0b\x32%.bilibili.pgc.gateway.player.v2.Toast\x12\x41\n\x12toast_without_time\x18\x06 \x01(\x0b\x32%.bilibili.pgc.gateway.player.v2.Toast\x12\x15\n\rlast_play_aid\x18\x07 \x01(\x03*|\n\x08\x43lipType\x12\x0e\n\nNT_UNKNOWN\x10\x00\x12\x10\n\x0c\x43LIP_TYPE_OP\x10\x01\x12\x10\n\x0c\x43LIP_TYPE_ED\x10\x02\x12\x10\n\x0c\x43LIP_TYPE_HE\x10\x03\x12\x18\n\x14\x43LIP_TYPE_MULTI_VIEW\x10\x04\x12\x10\n\x0c\x43LIP_TYPE_AD\x10\x05*0\n\x08\x43odeType\x12\n\n\x06NOCODE\x10\x00\x12\x0b\n\x07\x43ODE264\x10\x01\x12\x0b\n\x07\x43ODE265\x10\x02*B\n\x0b\x44rmTechType\x12\x07\n\x03NON\x10\x00\x12\r\n\tFAIR_PLAY\x10\x01\x12\r\n\tWIDE_VINE\x10\x02\x12\x0c\n\x08\x42ILI_DRM\x10\x03*+\n\x14\x45pPublicityVideoType\x12\x07\n\x03PRE\x10\x00\x12\n\n\x06INLINE\x10\x01*<\n\x0bInlineScene\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nRELATED_EP\x10\x01\x12\x06\n\x02HE\x10\x02\x12\x08\n\x04SKIP\x10\x03*R\n\nInlineType\x12\x10\n\x0cTYPE_UNKNOWN\x10\x00\x12\x0e\n\nTYPE_WHOLE\x10\x01\x12\x10\n\x0cTYPE_HE_CLIP\x10\x02\x12\x10\n\x0cTYPE_PREVIEW\x10\x03*N\n\x0fLimitActionType\x12\x0f\n\x0bLAT_UNKNOWN\x10\x00\x12\x15\n\x11SHOW_LIMIT_DIALOG\x10\x01\x12\x13\n\x0fSKIP_CURRENT_EP\x10\x02*1\n\x07PlayErr\x12\t\n\x05NoErr\x10\x00\x12\x1b\n\x17WithMultiDeviceLoginErr\x10\x01*L\n\rSecurityLevel\x12\x11\n\rLEVEL_UNKNOWN\x10\x00\x12\x0c\n\x08LEVEL_L1\x10\x01\x12\x0c\n\x08LEVEL_L2\x10\x02\x12\x0c\n\x08LEVEL_L3\x10\x03\x32\xde\x01\n\x07PlayURL\x12\x66\n\x08PlayView\x12+.bilibili.pgc.gateway.player.v2.PlayViewReq\x1a-.bilibili.pgc.gateway.player.v2.PlayViewReply\x12k\n\rPlayViewComic\x12+.bilibili.pgc.gateway.player.v2.PlayViewReq\x1a-.bilibili.pgc.gateway.player.v2.PlayViewReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.pgc.gateway.player.v2.playurl_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ANIMATION_QNSVGAANIMATIONMAPENTRY._options = None
  _ANIMATION_QNSVGAANIMATIONMAPENTRY._serialized_options = b'8\001'
  _BUTTONINFO_ORDERREPORTPARAMSENTRY._options = None
  _BUTTONINFO_ORDERREPORTPARAMSENTRY._serialized_options = b'8\001'
  _PAYTIP_ORDERREPORTPARAMSENTRY._options = None
  _PAYTIP_ORDERREPORTPARAMSENTRY._serialized_options = b'8\001'
  _PLAYVIEWBUSINESSINFO_QUALITYEXTMAPENTRY._options = None
  _PLAYVIEWBUSINESSINFO_QUALITYEXTMAPENTRY._serialized_options = b'8\001'
  _PLAYVIEWBUSINESSINFO_EXPMAPENTRY._options = None
  _PLAYVIEWBUSINESSINFO_EXPMAPENTRY._serialized_options = b'8\001'
  _TOAST_ORDERREPORTPARAMSENTRY._options = None
  _TOAST_ORDERREPORTPARAMSENTRY._serialized_options = b'8\001'
  _VIEWINFO_EXPCONFIGENTRY._options = None
  _VIEWINFO_EXPCONFIGENTRY._serialized_options = b'8\001'
  _VIEWINFO_EXTDIALOGENTRY._options = None
  _VIEWINFO_EXTDIALOGENTRY._serialized_options = b'8\001'
  _VIEWINFO_EXTTOASTENTRY._options = None
  _VIEWINFO_EXTTOASTENTRY._serialized_options = b'8\001'
  _globals['_CLIPTYPE']._serialized_start=15113
  _globals['_CLIPTYPE']._serialized_end=15237
  _globals['_CODETYPE']._serialized_start=15239
  _globals['_CODETYPE']._serialized_end=15287
  _globals['_DRMTECHTYPE']._serialized_start=15289
  _globals['_DRMTECHTYPE']._serialized_end=15355
  _globals['_EPPUBLICITYVIDEOTYPE']._serialized_start=15357
  _globals['_EPPUBLICITYVIDEOTYPE']._serialized_end=15400
  _globals['_INLINESCENE']._serialized_start=15402
  _globals['_INLINESCENE']._serialized_end=15462
  _globals['_INLINETYPE']._serialized_start=15464
  _globals['_INLINETYPE']._serialized_end=15546
  _globals['_LIMITACTIONTYPE']._serialized_start=15548
  _globals['_LIMITACTIONTYPE']._serialized_end=15626
  _globals['_PLAYERR']._serialized_start=15628
  _globals['_PLAYERR']._serialized_end=15677
  _globals['_SECURITYLEVEL']._serialized_start=15679
  _globals['_SECURITYLEVEL']._serialized_end=15755
  _globals['_ANIMATION']._serialized_start=114
  _globals['_ANIMATION']._serialized_end=282
  _globals['_ANIMATION_QNSVGAANIMATIONMAPENTRY']._serialized_start=225
  _globals['_ANIMATION_QNSVGAANIMATIONMAPENTRY']._serialized_end=282
  _globals['_AUDIOMATERIALPROTO']._serialized_start=285
  _globals['_AUDIOMATERIALPROTO']._serialized_end=475
  _globals['_BADGEINFO']._serialized_start=478
  _globals['_BADGEINFO']._serialized_end=652
  _globals['_BOTTOMDISPLAY']._serialized_start=654
  _globals['_BOTTOMDISPLAY']._serialized_end=740
  _globals['_BUTTONINFO']._serialized_start=743
  _globals['_BUTTONINFO']._serialized_end=1476
  _globals['_BUTTONINFO_ORDERREPORTPARAMSENTRY']._serialized_start=1420
  _globals['_BUTTONINFO_ORDERREPORTPARAMSENTRY']._serialized_end=1476
  _globals['_CASTTIPS']._serialized_start=1478
  _globals['_CASTTIPS']._serialized_end=1519
  _globals['_CLIPINFO']._serialized_start=1522
  _globals['_CLIPINFO']._serialized_end=1725
  _globals['_CONTINUEPLAYINFO']._serialized_start=1727
  _globals['_CONTINUEPLAYINFO']._serialized_end=1774
  _globals['_COUPON']._serialized_start=1777
  _globals['_COUPON']._serialized_end=2047
  _globals['_COUPONINFO']._serialized_start=2050
  _globals['_COUPONINFO']._serialized_end=2179
  _globals['_COUPONTEXTINFO']._serialized_start=2181
  _globals['_COUPONTEXTINFO']._serialized_end=2240
  _globals['_COUPONTOAST']._serialized_start=2243
  _globals['_COUPONTOAST']._serialized_end=2383
  _globals['_DASHITEM']._serialized_start=2386
  _globals['_DASHITEM']._serialized_end=2552
  _globals['_DASHVIDEO']._serialized_start=2555
  _globals['_DASHVIDEO']._serialized_end=2779
  _globals['_DATACONTROL']._serialized_start=2781
  _globals['_DATACONTROL']._serialized_end=2823
  _globals['_DIALOG']._serialized_start=2826
  _globals['_DIALOG']._serialized_end=3538
  _globals['_DIALOGCONFIG']._serialized_start=3541
  _globals['_DIALOGCONFIG']._serialized_end=3720
  _globals['_DIMENSION']._serialized_start=3722
  _globals['_DIMENSION']._serialized_end=3780
  _globals['_DOLBYITEM']._serialized_start=3783
  _globals['_DOLBYITEM']._serialized_end=3954
  _globals['_DOLBYITEM_TYPE']._serialized_start=3915
  _globals['_DOLBYITEM_TYPE']._serialized_end=3954
  _globals['_ENDPAGE']._serialized_start=3956
  _globals['_ENDPAGE']._serialized_end=4035
  _globals['_EPINLINEVIDEO']._serialized_start=4037
  _globals['_EPINLINEVIDEO']._serialized_end=4099
  _globals['_EPISODEADVERTISEMENTINFO']._serialized_start=4102
  _globals['_EPISODEADVERTISEMENTINFO']._serialized_end=4300
  _globals['_EPISODEINFO']._serialized_start=4303
  _globals['_EPISODEINFO']._serialized_end=4557
  _globals['_EPPREVIDEO']._serialized_start=4559
  _globals['_EPPREVIDEO']._serialized_end=4597
  _globals['_EPPUBLICITYVIDEO']._serialized_start=4600
  _globals['_EPPUBLICITYVIDEO']._serialized_end=4896
  _globals['_EPPUBLICITYVIDEO_TYPE']._serialized_start=4831
  _globals['_EPPUBLICITYVIDEO_TYPE']._serialized_end=4888
  _globals['_EVENT']._serialized_start=4898
  _globals['_EVENT']._serialized_end=4959
  _globals['_FREYACONFIG']._serialized_start=4962
  _globals['_FREYACONFIG']._serialized_end=5098
  _globals['_GRADIENTCOLOR']._serialized_start=5100
  _globals['_GRADIENTCOLOR']._serialized_end=5155
  _globals['_HIGHDEFINITIONTRIALINFO']._serialized_start=5158
  _globals['_HIGHDEFINITIONTRIALINFO']._serialized_end=5585
  _globals['_HISTORYNODE']._serialized_start=5587
  _globals['_HISTORYNODE']._serialized_end=5645
  _globals['_IMAGEINFO']._serialized_start=5647
  _globals['_IMAGEINFO']._serialized_end=5671
  _globals['_INTERACTION']._serialized_start=5674
  _globals['_INTERACTION']._serialized_end=5814
  _globals['_MULTIVIEW']._serialized_start=5816
  _globals['_MULTIVIEW']._serialized_end=5894
  _globals['_PAYTIP']._serialized_start=5897
  _globals['_PAYTIP']._serialized_end=6519
  _globals['_PAYTIP_ORDERREPORTPARAMSENTRY']._serialized_start=1420
  _globals['_PAYTIP_ORDERREPORTPARAMSENTRY']._serialized_end=1476
  _globals['_PLAYABILITYCONF']._serialized_start=6522
  _globals['_PLAYABILITYCONF']._serialized_end=7424
  _globals['_PLAYABILITYEXTCONF']._serialized_start=7427
  _globals['_PLAYABILITYEXTCONF']._serialized_end=7605
  _globals['_PLAYDUBBINGINFO']._serialized_start=7608
  _globals['_PLAYDUBBINGINFO']._serialized_end=7796
  _globals['_PLAYEXTINFO']._serialized_start=7798
  _globals['_PLAYEXTINFO']._serialized_end=7887
  _globals['_PLAYLIST']._serialized_start=7890
  _globals['_PLAYLIST']._serialized_end=8026
  _globals['_PLAYVIEWBUSINESSINFO']._serialized_start=8029
  _globals['_PLAYVIEWBUSINESSINFO']._serialized_end=9201
  _globals['_PLAYVIEWBUSINESSINFO_QUALITYEXTMAPENTRY']._serialized_start=9054
  _globals['_PLAYVIEWBUSINESSINFO_QUALITYEXTMAPENTRY']._serialized_end=9154
  _globals['_PLAYVIEWBUSINESSINFO_EXPMAPENTRY']._serialized_start=9156
  _globals['_PLAYVIEWBUSINESSINFO_EXPMAPENTRY']._serialized_end=9201
  _globals['_PLAYVIEWREPLY']._serialized_start=9204
  _globals['_PLAYVIEWREPLY']._serialized_end=9680
  _globals['_PLAYVIEWREQ']._serialized_start=9683
  _globals['_PLAYVIEWREQ']._serialized_end=10277
  _globals['_POPWIN']._serialized_start=10280
  _globals['_POPWIN']._serialized_end=10659
  _globals['_PROMPTBAR']._serialized_start=10662
  _globals['_PROMPTBAR']._serialized_end=11138
  _globals['_QUALITYEXTINFO']._serialized_start=11140
  _globals['_QUALITYEXTINFO']._serialized_end=11179
  _globals['_RECORDINFO']._serialized_start=11181
  _globals['_RECORDINFO']._serialized_end=11230
  _globals['_REPORT']._serialized_start=11232
  _globals['_REPORT']._serialized_end=11304
  _globals['_RESPONSEURL']._serialized_start=11306
  _globals['_RESPONSEURL']._serialized_end=11410
  _globals['_RIGHTS']._serialized_start=11412
  _globals['_RIGHTS']._serialized_end=11439
  _globals['_ROLEAUDIOPROTO']._serialized_start=11442
  _globals['_ROLEAUDIOPROTO']._serialized_end=11596
  _globals['_SCENECONTROL']._serialized_start=11598
  _globals['_SCENECONTROL']._serialized_end=11715
  _globals['_SCHEME']._serialized_start=11718
  _globals['_SCHEME']._serialized_end=11856
  _globals['_SCHEME_ACTIONTYPE']._serialized_start=11815
  _globals['_SCHEME_ACTIONTYPE']._serialized_end=11856
  _globals['_SEASONINFO']._serialized_start=11859
  _globals['_SEASONINFO']._serialized_end=12034
  _globals['_SEGMENTVIDEO']._serialized_start=12036
  _globals['_SEGMENTVIDEO']._serialized_end=12112
  _globals['_SHAKE']._serialized_start=12114
  _globals['_SHAKE']._serialized_end=12135
  _globals['_STREAM']._serialized_start=12138
  _globals['_STREAM']._serialized_end=12351
  _globals['_STREAMINFO']._serialized_start=12354
  _globals['_STREAMINFO']._serialized_end=12734
  _globals['_STREAMLIMIT']._serialized_start=12736
  _globals['_STREAMLIMIT']._serialized_end=12790
  _globals['_TASKPARAM']._serialized_start=12792
  _globals['_TASKPARAM']._serialized_end=12860
  _globals['_TEXTINFO']._serialized_start=12862
  _globals['_TEXTINFO']._serialized_end=12932
  _globals['_TOAST']._serialized_start=12935
  _globals['_TOAST']._serialized_end=13322
  _globals['_TOAST_ORDERREPORTPARAMSENTRY']._serialized_start=1420
  _globals['_TOAST_ORDERREPORTPARAMSENTRY']._serialized_end=1476
  _globals['_USERSTATUS']._serialized_start=13325
  _globals['_USERSTATUS']._serialized_end=13519
  _globals['_VIDEOINFO']._serialized_start=13522
  _globals['_VIDEOINFO']._serialized_end=13790
  _globals['_VIEWINFO']._serialized_start=13793
  _globals['_VIEWINFO']._serialized_end=14865
  _globals['_VIEWINFO_EXPCONFIGENTRY']._serialized_start=14639
  _globals['_VIEWINFO_EXPCONFIGENTRY']._serialized_end=14687
  _globals['_VIEWINFO_EXTDIALOGENTRY']._serialized_start=14689
  _globals['_VIEWINFO_EXTDIALOGENTRY']._serialized_end=14777
  _globals['_VIEWINFO_EXTTOASTENTRY']._serialized_start=14779
  _globals['_VIEWINFO_EXTTOASTENTRY']._serialized_end=14865
  _globals['_WATCHPROGRESS']._serialized_start=14868
  _globals['_WATCHPROGRESS']._serialized_end=15111
  _globals['_PLAYURL']._serialized_start=15758
  _globals['_PLAYURL']._serialized_end=15980
# @@protoc_insertion_point(module_scope)



import time
import re
from hashlib import md5
from typing import Any, Dict, Optional, Union, Tuple
from urllib.parse import urlencode

from httpx import AsyncClient
from httpx._models import Response
from httpx._types import HeaderTypes, ProxiesTypes, URLTypes

from .._typing import T_Auth
from ..auth import Auth
from ..exceptions import ResponseCodeError

DEFAULT_HEADERS = {
    "user-agent": (
        "Mozilla/5.0 (Windows NT 10.0; Win64; x64)"
        " AppleWebKit/537.36 (KHTML, like Gecko) Chrome/87.0.4280.88"
        " Safari/537.36 Edg/87.0.664.60"
    ),
    "Referer": "https://www.bilibili.com/",
}
APPKEY = "4409e2ce8ffd12b8"
APPSEC = "59b43e04ad6965f34319062b478f83dd"
homepage_cookies: Dict[str, str] = {}
_salt = None


async def get_homepage_cookies(proxies=None):
    if not homepage_cookies:
        async with AsyncClient(proxies=proxies) as client:
            resp = await client.request(
                "GET",
                "https://www.bilibili.com/",
                headers=DEFAULT_HEADERS,
                follow_redirects=True,
            )
        resp.encoding = "utf-8"
        homepage_cookies.update(resp.cookies)
    return homepage_cookies


def _encrypt_params(params: Dict[str, Any], local_id: int = 0) -> Dict[str, Any]:
    params["local_id"] = local_id
    params["appkey"] = APPKEY
    params["ts"] = int(time.time())
    params["sign"] = md5(
        f"{urlencode(sorted(params.items()))}{APPSEC}".encode("utf-8")
    ).hexdigest()
    return params


async def _getsalt(*, proxies: ProxiesTypes = {"all://": None}):
    async with AsyncClient(proxies=proxies) as client:
        url = "https://api.bilibili.com/x/web-interface/nav"
        req = await client.request("GET", url, headers=DEFAULT_HEADERS)
    con = req.json()
    img_url = con["data"]["wbi_img"]["img_url"]
    sub_url = con["data"]["wbi_img"]["sub_url"]
    re_rule = r"wbi/(.*?).png"
    img_key = "".join(re.findall(re_rule, img_url))
    sub_key = "".join(re.findall(re_rule, sub_url))
    n = img_key + sub_key
    array = list(n)
    # 注释fmt是为了阻止Black把下面的order格式化为更多行
    # fmt:off
    order = [46, 47, 18, 2, 53, 8, 23, 32, 15, 50, 10, 31, 58, 3, 45, 35, 27, 43, 5,49, 33, 9, 42, 19, 29, 28, 14, 39, 12, 38, 41, 13, 37, 48, 7,16, 24, 55, 40, 61, 26, 17, 0, 1, 60, 51, 30, 4, 22, 25, 54,21, 56, 59, 6, 63, 57, 62, 11, 36, 20, 34, 44, 52]
    # fmt:on
    salt = "".join([array[i] for i in order])[:32]
    return salt


async def _encrypt_w_rid(params: Union[str, dict]) -> Tuple[str, str]:
    """传入参数字符串返回签名和时间tuple[w_rid,wts]
    -----------
    params:str格式：qn=32&fnver=0&fnval=4048&fourk=1&voice_balance=1&gaia_source=pre-load&avid=593238479&bvid=BV16q4y1k7mq&cid=486645610\n
    params:dict格式：{'qn': '32', 'fnver': '0', 'fnval': '4048', 'fourk': '1', 'voice_balance': '1', 'gaia_source': 'pre-load', 'avid': '593238479', 'bvid': 'BV16q4y1k7mq', 'cid': '486645610'}：
    """
    global _salt
    wts = str(int(time.time()))
    if type(params) == str:
        params_list = (params + "&wts=" + wts).split("&")
    elif type(params) == dict:
        params["wts"] = wts
        params_list = [f"{key}={value}" for key, value in params.items()]
    else:
        raise Exception(f"invalid type of e:{type(params)}")
    params_list.sort()
    if _salt is None:
        _salt = await _getsalt()
    w_rid = md5(("&".join(params_list) + _salt).encode(encoding="utf-8")).hexdigest()
    return w_rid, wts


async def _sign_params(params: Dict[str, Any]):
    params.pop("w_rid", "")
    params.pop("wts", "")
    params["token"] = params.get("token", "")
    params["platform"] = params.get("platform", "web")
    params["web_location"] = params.get("web_location", 1550101)
    w_rid, wts = await _encrypt_w_rid(params)
    params["w_rid"] = w_rid
    params["wts"] = wts


async def _request(
    method: str,
    url: URLTypes,
    *,
    params: Optional[Dict[str, Any]] = None,
    cookies: Optional[Dict[str, Any]] = None,
    auth: T_Auth = None,
    reqtype: str = "app",
    is_wbi: bool = False,
    headers: HeaderTypes = DEFAULT_HEADERS,
    proxies: ProxiesTypes = {"all://": None},
    **kwargs,
) -> Response:
    auth = Auth(auth)
    if params is None:
        params = {}
    if cookies is None:
        cookies = {}
    if reqtype.lower() == "app":
        params.update(auth.tokens)
        _encrypt_params(params)
    else:
        cookies.update(auth.cookies)
    cookies.update(await get_homepage_cookies(proxies))
    if is_wbi:
        await _sign_params(params)
    async with AsyncClient(proxies=proxies) as client:
        resp = await client.request(
            method, url, headers=headers, params=params, cookies=cookies, **kwargs
        )
    resp.encoding = "utf-8"
    return resp


async def request(
    method: str, url: URLTypes, retry_time: int = 3, *, raw: bool = False, **kwargs
) -> Dict[str, Any]:
    raw_json: Dict[str, Any] = (await _request(method, url, **kwargs)).json()
    if raw:
        return raw_json
    if raw_json["code"] == -403:
        retry_time = retry_time - 1
        if retry_time < 0:
            raise ResponseCodeError(
                code=raw_json["code"],
                msg=raw_json["message"],
                data=raw_json.get("data", None),
            )
        global _salt
        _salt = await _getsalt()
        return await request(method, url, retry_time, **kwargs)
    if raw_json["code"] != 0:
        raise ResponseCodeError(
            code=raw_json["code"],
            msg=raw_json["message"],
            data=raw_json.get("data", None),
        )
    return raw_json["data"]


async def get(url: URLTypes, **kwargs):
    return await request("GET", url, **kwargs)


async def post(url: URLTypes, **kwargs):
    return await request("POST", url, **kwargs)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/metadata/fawkes/fawkes.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%bilibili/metadata/fawkes/fawkes.proto\x12\x18\x62ilibili.metadata.fawkes\")\n\x0b\x46\x61wkesReply\x12\x0e\n\x06\x63onfig\x18\x01 \x01(\t\x12\n\n\x02\x66\x66\x18\x02 \x01(\t\"<\n\tFawkesReq\x12\x0e\n\x06\x61ppkey\x18\x01 \x01(\t\x12\x0b\n\x03\x65nv\x18\x02 \x01(\t\x12\x12\n\nsession_id\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.metadata.fawkes.fawkes_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_FAWKESREPLY']._serialized_start=67
  _globals['_FAWKESREPLY']._serialized_end=108
  _globals['_FAWKESREQ']._serialized_start=110
  _globals['_FAWKESREQ']._serialized_end=170
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.card.v1.common_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class SmallCoverV5(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    COVER_GIF_FIELD_NUMBER: builtins.int
    UP_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_1_FIELD_NUMBER: builtins.int
    RIGHT_DESC_1_FIELD_NUMBER: builtins.int
    RIGHT_DESC_2_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    HOTWORD_ENTRANCE_FIELD_NUMBER: builtins.int
    CORNER_MARK_STYLE_FIELD_NUMBER: builtins.int
    RIGHT_ICON_1_FIELD_NUMBER: builtins.int
    RIGHT_ICON_2_FIELD_NUMBER: builtins.int
    LEFT_CORNER_MARK_STYLE_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_CONTENT_DESCRIPTION_FIELD_NUMBER: builtins.int
    RIGHT_DESC1_CONTENT_DESCRIPTION_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """条目基本信息"""
    cover_gif: builtins.str
    """"""
    @property
    def up(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Up:
        """"""
    cover_right_text_1: builtins.str
    """封面右下角标文案"""
    right_desc_1: builtins.str
    """右侧文案1"""
    right_desc_2: builtins.str
    """右侧文案2"""
    @property
    def rcmd_reason_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """右侧推荐原因标签框"""
    @property
    def hotword_entrance(self) -> global___HotwordEntrance:
        """"""
    @property
    def corner_mark_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """直播小卡的角标"""
    right_icon_1: builtins.int
    """右侧文案1图标id"""
    right_icon_2: builtins.int
    """右侧文案2图标id"""
    @property
    def left_corner_mark_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """左上角角标"""
    cover_right_text_content_description: builtins.str
    """"""
    right_desc1_content_description: builtins.str
    """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        cover_gif: builtins.str = ...,
        up: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Up | None = ...,
        cover_right_text_1: builtins.str = ...,
        right_desc_1: builtins.str = ...,
        right_desc_2: builtins.str = ...,
        rcmd_reason_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
        hotword_entrance: global___HotwordEntrance | None = ...,
        corner_mark_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
        right_icon_1: builtins.int = ...,
        right_icon_2: builtins.int = ...,
        left_corner_mark_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
        cover_right_text_content_description: builtins.str = ...,
        right_desc1_content_description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base", "corner_mark_style", b"corner_mark_style", "hotword_entrance", b"hotword_entrance", "left_corner_mark_style", b"left_corner_mark_style", "rcmd_reason_style", b"rcmd_reason_style", "up", b"up"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base", b"base", "corner_mark_style", b"corner_mark_style", "cover_gif", b"cover_gif", "cover_right_text_1", b"cover_right_text_1", "cover_right_text_content_description", b"cover_right_text_content_description", "hotword_entrance", b"hotword_entrance", "left_corner_mark_style", b"left_corner_mark_style", "rcmd_reason_style", b"rcmd_reason_style", "right_desc1_content_description", b"right_desc1_content_description", "right_desc_1", b"right_desc_1", "right_desc_2", b"right_desc_2", "right_icon_1", b"right_icon_1", "right_icon_2", b"right_icon_2", "up", b"up"]) -> None: ...

global___SmallCoverV5 = SmallCoverV5

@typing_extensions.final
class SmallCoverV5Ad(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    COVER_GIF_FIELD_NUMBER: builtins.int
    UP_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT1_FIELD_NUMBER: builtins.int
    RIGHT_DESC1_FIELD_NUMBER: builtins.int
    RIGHT_DESC2_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    HOTWORD_ENTRANCE_FIELD_NUMBER: builtins.int
    CORNER_MARK_STYLE_FIELD_NUMBER: builtins.int
    RIGHT_ICON1_FIELD_NUMBER: builtins.int
    RIGHT_ICON2_FIELD_NUMBER: builtins.int
    LEFT_CORNER_MARK_STYLE_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_CONTENT_DESCRIPTION_FIELD_NUMBER: builtins.int
    RIGHT_DESC1_CONTENT_DESCRIPTION_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """"""
    cover_gif: builtins.str
    """"""
    @property
    def up(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Up:
        """"""
    cover_right_text1: builtins.str
    """"""
    right_desc1: builtins.str
    """"""
    right_desc2: builtins.str
    """"""
    @property
    def rcmd_reason_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    @property
    def hotword_entrance(self) -> global___HotwordEntrance:
        """"""
    @property
    def corner_mark_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    right_icon1: builtins.int
    """"""
    right_icon2: builtins.int
    """"""
    @property
    def left_corner_mark_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    cover_right_text_content_description: builtins.str
    """"""
    right_desc1_content_description: builtins.str
    """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        cover_gif: builtins.str = ...,
        up: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Up | None = ...,
        cover_right_text1: builtins.str = ...,
        right_desc1: builtins.str = ...,
        right_desc2: builtins.str = ...,
        rcmd_reason_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
        hotword_entrance: global___HotwordEntrance | None = ...,
        corner_mark_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
        right_icon1: builtins.int = ...,
        right_icon2: builtins.int = ...,
        left_corner_mark_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
        cover_right_text_content_description: builtins.str = ...,
        right_desc1_content_description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base", "corner_mark_style", b"corner_mark_style", "hotword_entrance", b"hotword_entrance", "left_corner_mark_style", b"left_corner_mark_style", "rcmd_reason_style", b"rcmd_reason_style", "up", b"up"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base", b"base", "corner_mark_style", b"corner_mark_style", "cover_gif", b"cover_gif", "cover_right_text1", b"cover_right_text1", "cover_right_text_content_description", b"cover_right_text_content_description", "hotword_entrance", b"hotword_entrance", "left_corner_mark_style", b"left_corner_mark_style", "rcmd_reason_style", b"rcmd_reason_style", "right_desc1", b"right_desc1", "right_desc1_content_description", b"right_desc1_content_description", "right_desc2", b"right_desc2", "right_icon1", b"right_icon1", "right_icon2", b"right_icon2", "up", b"up"]) -> None: ...

global___SmallCoverV5Ad = SmallCoverV5Ad

@typing_extensions.final
class HotwordEntrance(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOTWORD_ID_FIELD_NUMBER: builtins.int
    HOT_TEXT_FIELD_NUMBER: builtins.int
    H5_URL_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    hotword_id: builtins.int
    """"""
    hot_text: builtins.str
    """"""
    h5_url: builtins.str
    """"""
    icon: builtins.str
    """"""
    def __init__(
        self,
        *,
        hotword_id: builtins.int = ...,
        hot_text: builtins.str = ...,
        h5_url: builtins.str = ...,
        icon: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["h5_url", b"h5_url", "hot_text", b"hot_text", "hotword_id", b"hotword_id", "icon", b"icon"]) -> None: ...

global___HotwordEntrance = HotwordEntrance

@typing_extensions.final
class LargeCoverV1(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    COVER_GIF_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_3_FIELD_NUMBER: builtins.int
    COVER_BADGE_FIELD_NUMBER: builtins.int
    TOP_RCMD_REASON_FIELD_NUMBER: builtins.int
    BOTTOM_RCMD_REASON_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    OFFICIAL_ICON_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    TOP_RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    BOTTOM_RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_V2_FIELD_NUMBER: builtins.int
    LEFT_COVER_BADGE_STYLE_FIELD_NUMBER: builtins.int
    RIGHT_COVER_BADGE_STYLE_FIELD_NUMBER: builtins.int
    COVER_BADGE_2_FIELD_NUMBER: builtins.int
    LIKE_BUTTON_FIELD_NUMBER: builtins.int
    TITLE_SINGLE_LINE_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """条目基本信息"""
    cover_gif: builtins.str
    """"""
    @property
    def avatar(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Avatar:
        """"""
    cover_left_text_1: builtins.str
    """"""
    cover_left_text_2: builtins.str
    """"""
    cover_left_text_3: builtins.str
    """"""
    cover_badge: builtins.str
    """"""
    top_rcmd_reason: builtins.str
    """"""
    bottom_rcmd_reason: builtins.str
    """"""
    desc: builtins.str
    """"""
    official_icon: builtins.int
    """"""
    can_play: builtins.int
    """"""
    @property
    def top_rcmd_reason_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    @property
    def bottom_rcmd_reason_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    @property
    def rcmd_reason_style_v2(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    @property
    def left_cover_badge_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    @property
    def right_cover_badge_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    cover_badge_2: builtins.str
    """"""
    @property
    def like_button(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.LikeButton:
        """"""
    title_single_line: builtins.int
    """"""
    cover_right_text: builtins.str
    """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        cover_gif: builtins.str = ...,
        avatar: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Avatar | None = ...,
        cover_left_text_1: builtins.str = ...,
        cover_left_text_2: builtins.str = ...,
        cover_left_text_3: builtins.str = ...,
        cover_badge: builtins.str = ...,
        top_rcmd_reason: builtins.str = ...,
        bottom_rcmd_reason: builtins.str = ...,
        desc: builtins.str = ...,
        official_icon: builtins.int = ...,
        can_play: builtins.int = ...,
        top_rcmd_reason_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
        bottom_rcmd_reason_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
        rcmd_reason_style_v2: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
        left_cover_badge_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
        right_cover_badge_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
        cover_badge_2: builtins.str = ...,
        like_button: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.LikeButton | None = ...,
        title_single_line: builtins.int = ...,
        cover_right_text: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "base", b"base", "bottom_rcmd_reason_style", b"bottom_rcmd_reason_style", "left_cover_badge_style", b"left_cover_badge_style", "like_button", b"like_button", "rcmd_reason_style_v2", b"rcmd_reason_style_v2", "right_cover_badge_style", b"right_cover_badge_style", "top_rcmd_reason_style", b"top_rcmd_reason_style"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "base", b"base", "bottom_rcmd_reason", b"bottom_rcmd_reason", "bottom_rcmd_reason_style", b"bottom_rcmd_reason_style", "can_play", b"can_play", "cover_badge", b"cover_badge", "cover_badge_2", b"cover_badge_2", "cover_gif", b"cover_gif", "cover_left_text_1", b"cover_left_text_1", "cover_left_text_2", b"cover_left_text_2", "cover_left_text_3", b"cover_left_text_3", "cover_right_text", b"cover_right_text", "desc", b"desc", "left_cover_badge_style", b"left_cover_badge_style", "like_button", b"like_button", "official_icon", b"official_icon", "rcmd_reason_style_v2", b"rcmd_reason_style_v2", "right_cover_badge_style", b"right_cover_badge_style", "title_single_line", b"title_single_line", "top_rcmd_reason", b"top_rcmd_reason", "top_rcmd_reason_style", b"top_rcmd_reason_style"]) -> None: ...

global___LargeCoverV1 = LargeCoverV1

@typing_extensions.final
class ThreeItemAllV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    TOP_RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    ITEM_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """条目基本信息"""
    @property
    def top_rcmd_reason_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    @property
    def item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TwoItemHV1Item]:
        """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        top_rcmd_reason_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
        item: collections.abc.Iterable[global___TwoItemHV1Item] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base", "top_rcmd_reason_style", b"top_rcmd_reason_style"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base", b"base", "item", b"item", "top_rcmd_reason_style", b"top_rcmd_reason_style"]) -> None: ...

global___ThreeItemAllV2 = ThreeItemAllV2

@typing_extensions.final
class TwoItemHV1Item(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_1_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    uri: builtins.str
    """"""
    param: builtins.str
    """"""
    @property
    def args(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Args:
        """"""
    goto: builtins.str
    """"""
    cover_left_text_1: builtins.str
    """"""
    cover_left_icon_1: builtins.int
    """"""
    cover_right_text: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        uri: builtins.str = ...,
        param: builtins.str = ...,
        args: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Args | None = ...,
        goto: builtins.str = ...,
        cover_left_text_1: builtins.str = ...,
        cover_left_icon_1: builtins.int = ...,
        cover_right_text: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["args", b"args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["args", b"args", "cover", b"cover", "cover_left_icon_1", b"cover_left_icon_1", "cover_left_text_1", b"cover_left_text_1", "cover_right_text", b"cover_right_text", "goto", b"goto", "param", b"param", "title", b"title", "uri", b"uri"]) -> None: ...

global___TwoItemHV1Item = TwoItemHV1Item

@typing_extensions.final
class RcmdOneItem(google.protobuf.message.Message):
    """推荐"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    TOPRCMDREASONSTYLE_FIELD_NUMBER: builtins.int
    ITEM_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """条目基本信息"""
    @property
    def topRcmdReasonStyle(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """标签框信息"""
    @property
    def item(self) -> global___SmallCoverRcmdItem:
        """小封面推荐内容信息"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        topRcmdReasonStyle: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
        item: global___SmallCoverRcmdItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base", "item", b"item", "topRcmdReasonStyle", b"topRcmdReasonStyle"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base", b"base", "item", b"item", "topRcmdReasonStyle", b"topRcmdReasonStyle"]) -> None: ...

global___RcmdOneItem = RcmdOneItem

@typing_extensions.final
class SmallCoverRcmdItem(google.protobuf.message.Message):
    """小封面推荐内容信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    COVERRIGHTTEXT1_FIELD_NUMBER: builtins.int
    RIGHTDESC1_FIELD_NUMBER: builtins.int
    RIGHTDESC2_FIELD_NUMBER: builtins.int
    COVERGIF_FIELD_NUMBER: builtins.int
    RIGHTICON1_FIELD_NUMBER: builtins.int
    RIGHTICON2_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_CONTENT_DESCRIPTION_FIELD_NUMBER: builtins.int
    RIGHT_DESC1_CONTENT_DESCRIPTION_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    cover: builtins.str
    """封面url"""
    uri: builtins.str
    """跳转uri"""
    param: builtins.str
    """参数"""
    goto: builtins.str
    """跳转类型
    av:视频稿件
    """
    coverRightText1: builtins.str
    """封面右下角标文案"""
    rightDesc1: builtins.str
    """右侧文案1"""
    rightDesc2: builtins.str
    """右侧文案2"""
    coverGif: builtins.str
    """"""
    rightIcon1: builtins.int
    """右侧文案1图标id"""
    rightIcon2: builtins.int
    """右侧文案2图标id"""
    cover_right_text_content_description: builtins.str
    """"""
    right_desc1_content_description: builtins.str
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        uri: builtins.str = ...,
        param: builtins.str = ...,
        goto: builtins.str = ...,
        coverRightText1: builtins.str = ...,
        rightDesc1: builtins.str = ...,
        rightDesc2: builtins.str = ...,
        coverGif: builtins.str = ...,
        rightIcon1: builtins.int = ...,
        rightIcon2: builtins.int = ...,
        cover_right_text_content_description: builtins.str = ...,
        right_desc1_content_description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "coverGif", b"coverGif", "coverRightText1", b"coverRightText1", "cover_right_text_content_description", b"cover_right_text_content_description", "goto", b"goto", "param", b"param", "rightDesc1", b"rightDesc1", "rightDesc2", b"rightDesc2", "rightIcon1", b"rightIcon1", "rightIcon2", b"rightIcon2", "right_desc1_content_description", b"right_desc1_content_description", "title", b"title", "uri", b"uri"]) -> None: ...

global___SmallCoverRcmdItem = SmallCoverRcmdItem

@typing_extensions.final
class ThreeItemV1(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    TITLEICON_FIELD_NUMBER: builtins.int
    MOREURI_FIELD_NUMBER: builtins.int
    MORETEXT_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """条目基本信息"""
    titleIcon: builtins.int
    """"""
    moreUri: builtins.str
    """"""
    moreText: builtins.str
    """"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThreeItemV1Item]:
        """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        titleIcon: builtins.int = ...,
        moreUri: builtins.str = ...,
        moreText: builtins.str = ...,
        items: collections.abc.Iterable[global___ThreeItemV1Item] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base", b"base", "items", b"items", "moreText", b"moreText", "moreUri", b"moreUri", "titleIcon", b"titleIcon"]) -> None: ...

global___ThreeItemV1 = ThreeItemV1

@typing_extensions.final
class ThreeItemV1Item(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    COVERLEFTTEXT_FIELD_NUMBER: builtins.int
    COVERLEFTICON_FIELD_NUMBER: builtins.int
    DESC1_FIELD_NUMBER: builtins.int
    DESC2_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """条目基本信息"""
    coverLeftText: builtins.str
    """"""
    coverLeftIcon: builtins.int
    """"""
    desc1: builtins.str
    """"""
    desc2: builtins.str
    """"""
    badge: builtins.str
    """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        coverLeftText: builtins.str = ...,
        coverLeftIcon: builtins.int = ...,
        desc1: builtins.str = ...,
        desc2: builtins.str = ...,
        badge: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "base", b"base", "coverLeftIcon", b"coverLeftIcon", "coverLeftText", b"coverLeftText", "desc1", b"desc1", "desc2", b"desc2"]) -> None: ...

global___ThreeItemV1Item = ThreeItemV1Item

@typing_extensions.final
class HotTopicItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COVER_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    cover: builtins.str
    """"""
    uri: builtins.str
    """"""
    param: builtins.str
    """"""
    name: builtins.str
    """"""
    def __init__(
        self,
        *,
        cover: builtins.str = ...,
        uri: builtins.str = ...,
        param: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "name", b"name", "param", b"param", "uri", b"uri"]) -> None: ...

global___HotTopicItem = HotTopicItem

@typing_extensions.final
class HotTopic(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """条目基本信息"""
    desc: builtins.str
    """"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HotTopicItem]:
        """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        desc: builtins.str = ...,
        items: collections.abc.Iterable[global___HotTopicItem] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base", b"base", "desc", b"desc", "items", b"items"]) -> None: ...

global___HotTopic = HotTopic

@typing_extensions.final
class DynamicHot(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    TOP_LEFT_TITLE_FIELD_NUMBER: builtins.int
    DESC1_FIELD_NUMBER: builtins.int
    DESC2_FIELD_NUMBER: builtins.int
    MORE_URI_FIELD_NUMBER: builtins.int
    MORE_TEXT_FIELD_NUMBER: builtins.int
    COVERS_FIELD_NUMBER: builtins.int
    COVER_RIGHT_TEXT_FIELD_NUMBER: builtins.int
    TOP_RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """条目基本信息"""
    top_left_title: builtins.str
    """"""
    desc1: builtins.str
    """"""
    desc2: builtins.str
    """"""
    more_uri: builtins.str
    """"""
    more_text: builtins.str
    """"""
    @property
    def covers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    cover_right_text: builtins.str
    """"""
    @property
    def top_rcmd_reason_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        top_left_title: builtins.str = ...,
        desc1: builtins.str = ...,
        desc2: builtins.str = ...,
        more_uri: builtins.str = ...,
        more_text: builtins.str = ...,
        covers: collections.abc.Iterable[builtins.str] | None = ...,
        cover_right_text: builtins.str = ...,
        top_rcmd_reason_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base", "top_rcmd_reason_style", b"top_rcmd_reason_style"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base", b"base", "cover_right_text", b"cover_right_text", "covers", b"covers", "desc1", b"desc1", "desc2", b"desc2", "more_text", b"more_text", "more_uri", b"more_uri", "top_left_title", b"top_left_title", "top_rcmd_reason_style", b"top_rcmd_reason_style"]) -> None: ...

global___DynamicHot = DynamicHot

@typing_extensions.final
class MiddleCoverV3(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    DESC1_FIELD_NUMBER: builtins.int
    DESC2_FIELD_NUMBER: builtins.int
    COVER_BADGE_STYLE_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """条目基本信息"""
    desc1: builtins.str
    """"""
    desc2: builtins.str
    """"""
    @property
    def cover_badge_style(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle:
        """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        desc1: builtins.str = ...,
        desc2: builtins.str = ...,
        cover_badge_style: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.ReasonStyle | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base", "cover_badge_style", b"cover_badge_style"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base", b"base", "cover_badge_style", b"cover_badge_style", "desc1", b"desc1", "desc2", b"desc2"]) -> None: ...

global___MiddleCoverV3 = MiddleCoverV3

@typing_extensions.final
class LargeCoverV4(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_3_FIELD_NUMBER: builtins.int
    COVER_BADGE_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    UP_FIELD_NUMBER: builtins.int
    SHORT_LINK_FIELD_NUMBER: builtins.int
    SHARE_SUBTITLE_FIELD_NUMBER: builtins.int
    PLAY_NUMBER_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    SUB_PARAM_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """条目基本信息"""
    cover_left_text_1: builtins.str
    """"""
    cover_left_text_2: builtins.str
    """"""
    cover_left_text_3: builtins.str
    """"""
    cover_badge: builtins.str
    """"""
    can_play: builtins.int
    """"""
    @property
    def up(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Up:
        """"""
    short_link: builtins.str
    """"""
    share_subtitle: builtins.str
    """"""
    play_number: builtins.str
    """"""
    bvid: builtins.str
    """"""
    sub_param: builtins.str
    """"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        cover_left_text_1: builtins.str = ...,
        cover_left_text_2: builtins.str = ...,
        cover_left_text_3: builtins.str = ...,
        cover_badge: builtins.str = ...,
        can_play: builtins.int = ...,
        up: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Up | None = ...,
        short_link: builtins.str = ...,
        share_subtitle: builtins.str = ...,
        play_number: builtins.str = ...,
        bvid: builtins.str = ...,
        sub_param: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base", "up", b"up"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base", b"base", "bvid", b"bvid", "can_play", b"can_play", "cover_badge", b"cover_badge", "cover_left_text_1", b"cover_left_text_1", "cover_left_text_2", b"cover_left_text_2", "cover_left_text_3", b"cover_left_text_3", "play_number", b"play_number", "share_subtitle", b"share_subtitle", "short_link", b"short_link", "sub_param", b"sub_param", "up", b"up"]) -> None: ...

global___LargeCoverV4 = LargeCoverV4

@typing_extensions.final
class PopularTopEntrance(google.protobuf.message.Message):
    """热门列表顶部按钮"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def base(self) -> bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base:
        """条目基本信息"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EntranceItem]:
        """按钮项"""
    def __init__(
        self,
        *,
        base: bilireq.grpc.protos.bilibili.app.card.v1.common_pb2.Base | None = ...,
        items: collections.abc.Iterable[global___EntranceItem] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base", b"base"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base", b"base", "items", b"items"]) -> None: ...

global___PopularTopEntrance = PopularTopEntrance

@typing_extensions.final
class EntranceItem(google.protobuf.message.Message):
    """热门列表按钮信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GOTO_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    MODULE_ID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ENTRANCE_ID_FIELD_NUMBER: builtins.int
    BUBBLE_FIELD_NUMBER: builtins.int
    ENTRANCE_TYPE_FIELD_NUMBER: builtins.int
    goto: builtins.str
    """跳转类型"""
    icon: builtins.str
    """图标url"""
    title: builtins.str
    """标题"""
    module_id: builtins.str
    """入口模块id"""
    uri: builtins.str
    """跳转uri"""
    entrance_id: builtins.int
    """入口id"""
    @property
    def bubble(self) -> global___Bubble:
        """气泡信息"""
    entrance_type: builtins.int
    """入口类型
    1:代表分品类热门
    """
    def __init__(
        self,
        *,
        goto: builtins.str = ...,
        icon: builtins.str = ...,
        title: builtins.str = ...,
        module_id: builtins.str = ...,
        uri: builtins.str = ...,
        entrance_id: builtins.int = ...,
        bubble: global___Bubble | None = ...,
        entrance_type: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bubble", b"bubble"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bubble", b"bubble", "entrance_id", b"entrance_id", "entrance_type", b"entrance_type", "goto", b"goto", "icon", b"icon", "module_id", b"module_id", "title", b"title", "uri", b"uri"]) -> None: ...

global___EntranceItem = EntranceItem

@typing_extensions.final
class Bubble(google.protobuf.message.Message):
    """气泡信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUBBLE_CONTENT_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    STIME_FIELD_NUMBER: builtins.int
    bubble_content: builtins.str
    """文案"""
    version: builtins.int
    """版本"""
    stime: builtins.int
    """起始时间"""
    def __init__(
        self,
        *,
        bubble_content: builtins.str = ...,
        version: builtins.int = ...,
        stime: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bubble_content", b"bubble_content", "stime", b"stime", "version", b"version"]) -> None: ...

global___Bubble = Bubble
